# Changelog
### v1.3.2
Release date:
- Support Python 3.14
- Fix UTF-8 file names on Windows

### v1.3.1
Release date: 2025-10-31
- Avoid onnxruntime bug on win32

### v1.3.0
Release date: 2025-09-23
- New export feature for darktable XMP files
- Preserve EXIF and embedded ICC profiles in TIFF, PNG, WebP

### v1.2.2
Release date: 2025-08-18
- Fix piexif.transfer (skip non-JPEG images)

### v1.2.1
Release date: 2025-07-05
- Fix inference with saturation-first

### v1.2.0
Release date: 2025-05-28
- Add support for ONNX models

### v1.1.4
Release date: 2025-05-09
- Return image as BytesIO

### v1.1.3
Release date: 2025-04-25
- Pass images as BytesIO

### v1.1.2
Release date: 2025-04-17
- Pass argv to RetroShine

### v1.1.1
Release date: 2025-04-17
- Support RetroShine fast preview with loaded_model

### v1.1.0
Release date: 2025-04-16
- 16/48-bit support for PNG, TIFF
- Support ICC-profiles
- Callback and improved support for RetroShine

### v1.0.1
Released date: 2015-04-16
- github workflow
- test against PIL 11

### v1.0.0
Release date: 2024-11-08
- Simplified CLI options
- Python f-string options
- Semantic Versioning
- Tests and pyproject.toml

### v0.2.0
Release date: 2024-09-03
- Support Free Curve Inference models

### v0.1.0
Release date: 2024-01-21
- JPEG: Preserve EXIF and quality
- Add Versioning
- Add Changelog
- Dump version/parameters in comment/EXIF
